"""
ARENA-py

Draw objects in the ARENA using Python!
"""

__version__ = "0.1.0"
__author__ = "Conix Research Center"
__credits__ = "WiSE Lab, Carnegie Mellon University"

from .arena import *
from .auth import *
